==> ImageMagick-4.2.2.tar.gz: ImageMagick-4.2.2/acconfig.h <==

/* Define to empty if the keyword does not work.  */
#undef const

/* Define if you don't have vprintf but do have _doprnt.  */
#undef HAVE_DOPRNT

/* Define if you have <sys/wait.h> that is POSIX.1 compatible.  */
#undef HAVE_SYS_WAIT_H

/* Define if you have the vprintf function.  */
#undef HAVE_VPRINTF

/* Define to `int' if <sys/types.h> doesn't define.  */
#undef mode_t

/* Define to `int' if <sys/types.h> doesn't define.  */
#undef pid_t

/* Define as the return type of signal handlers (int or void).  */
#undef RETSIGTYPE

/* Define to `unsigned' if <sys/types.h> doesn't define.  */
#undef size_t

/* Define if you have the snprintf function.  */
#undef HAVE_SNPRINTF

/* Define if you have the vsnprintf function.  */
#undef HAVE_VSNPRINTF

/* Define if you have the ANSI C header files.  */
#undef STDC_HEADERS

/* Define on System V Release 4.  */
#undef SVR4

/* Define if you can safely include both <sys/time.h> and <time.h>.  */
#undef TIME_WITH_SYS_TIME

/* Define if the X Window System is missing or not being used.  */
#undef X_DISPLAY_MISSING

/* Include patented LZW compression */
#undef HasLZW

/* X11 server supports shape extension */
#undef HasShape

/* X11 server supports shared memory extension */
#undef HasSharedMemory

/* Increase max color value from 255 to 65535 */
#undef QuantumLeap

/* Location of X11 RGB database */
#undef RGBColorDatabase

/* Define if you have the bzip2 library */
#undef HasBZLIB

/* Define if you have Display Postscript */
#undef HasDPS

/* Define if you have FlashPIX library */
#undef HasFPX

/* Define if you have HDF library */
#undef HasHDF

/* Define if you have JBIG library */
#undef HasJBIG

/* Define if you have JPEG library */
#undef HasJPEG

/* Define if you have MPEG library */
#undef HasMPEG

/* Define if you have PNG library */
#undef HasPNG

/* Define if you have TIFF library */
#undef HasTIFF

/* Define if you have FreeType (TrueType font) library */
#undef HasTTF

/* Define to specify default TrueType font path. */
#undef TT_FONT_PATH

/* Define if you have the SFIO mmap-based stdio library emulation */
#undef HasSFIO

/* Define if you have zlib compression library */
#undef HasZLIB

/* Define if you have debugging malloc library */
#undef WITH_DMALLOC

/* Define if you have sys_errlist[] in libc */
#undef HAVE_SYS_ERRLIST

/* Define if you have the getcwd function.  */
#undef HAVE_GETCWD

/* Define if you have the gethostname function.  */
#undef HAVE_GETHOSTNAME

/* Define if you have the mkdir function.  */
#undef HAVE_MKDIR

/* Define if you have the select function.  */
#undef HAVE_SELECT

/* Define if you have the strcspn function.  */
#undef HAVE_STRCSPN

/* Define if you have the strerror function.  */
#undef HAVE_STRERROR

/* Define if you have the strtol function.  */
#undef HAVE_STRTOL

/* Define if you have the <dirent.h> header file.  */
#undef HAVE_DIRENT_H

/* Define if you have the <fcntl.h> header file.  */
#undef HAVE_FCNTL_H

/* Define if you have the <ndir.h> header file.  */
#undef HAVE_NDIR_H

/* Define if you have the <strings.h> header file.  */
#undef HAVE_STRINGS_H

/* Define if you have the <sys/dir.h> header file.  */
#undef HAVE_SYS_DIR_H

/* Define if you have the <sys/file.h> header file.  */
#undef HAVE_SYS_FILE_H

/* Define if you have the <sys/ndir.h> header file.  */
#undef HAVE_SYS_NDIR_H

/* Define if you have the <sys/time.h> header file.  */
#undef HAVE_SYS_TIME_H

/* Define if you have the <unistd.h> header file.  */
#undef HAVE_UNISTD_H

/* Define if you have HP style pty allocation (/dev/ptym/ptyp*) */
#undef HAVE_PTYM

/* Define if you have HP style pty trapping (struct.*request_info in sys/ptyio.h) */
#undef HAVE_PTYTRAP

/* Define if you have AIX new-style pty allocation (/dev/ptc && /dev/pts) */
#undef HAVE_PTC_PTS

/* Define if you have SGI old-style pty allocation (/dev/ptc && ! /dev/pts) */
#undef HAVE_PTC

/* Define if you have SCO style pty allocation */
#undef HAVE_SCO_CLIST_PTYS

/* Define if you have SVR4 style pty allocation (/dev/ptmx) */
#undef HAVE_PTMX

/* Define if you have OSF/1 style pty allocation (/dev/ptmx_bsd) */
#undef HAVE_PTMX_BSD

/* Define directory where ImageMagick/delegates.h lives. (default /usr/local/share) */
#undef DelegatePath

/* Define location of 'bzip2' program */
#undef BZIPDelegate

/* Define location of 'compress' program */
#undef LZWEncodeDelegate

/* Define location of 'uncompress' program */
#undef LZWDecodeDelegate

/* Define location of 'gzip' program */
#undef ZipDelegate

/* Define location of WWW 'GET' program */
#undef WWWDecodeDelegate

/* Define location of 'hp2xx' program */
#undef HPGLDecodeDelegate

/* Define location of 'html2ps' program */
#undef HTMLDecodeDelegate

/* Define location of 'pgpv' program */
#undef PGPDecodeDelegate

/* Define location of the CGM support program 'ralcgm' */
#undef CGMDecodeDelegate

/* Define location of the Fig support program 'fig2dev' */
#undef FIGDecodeDelegate

/* Define location of the Postscript support program 'ps' */
#undef PSDelegate

/* Define location of the MPEG support program 'mpeg2decode' */
#undef MPEGDecodeDelegate

/* Define location of the MPEG support program 'mpeg2encode' */
#undef MPEGEncodeDelegate

/* Define location of the Radiance support program 'ra_ppm' */
#undef RADDecodeDelegate

/* Define location of the 'rawtorle' program */
#undef RLEEncodeDelegate

/* Define location of the 'scanimage' program */
#undef SCANDecodeDelegate

/* Define location of the 'netscape' program */
#undef BrowseDelegate

/* Define location of the 'groff' program */
#undef MANDelegate

/* Define location of the 'gimp' program */
#undef LaunchDelegate

/* Define location of the 'xterm' program */
#undef EditorDelegate

/* Define location of the 'display' program */
#undef ShowImageDelegate

/* Define location of the 'gimp' program */
#undef POVDelegate

/* Define location of the 'lp' program */
#undef LPDelegate

/* Define location of the 'convert' program */
#undef ConvertDelegate

/* Define location of the 'mogrify' program */
#undef MogrifyDelegate

/* Define location of the 'mv' program */
#undef MVDelegate

/* Define location of the 'rm' program */
#undef RMDelegate

/* Define location of the 'cat' program */
#undef CatDelegate

==> ImageMagick-4.2.6.tar.gz: ImageMagick-4.2.6/acconfig.h <==

/* Define to empty if the keyword does not work.  */
#undef const

/* Define if you don't have vprintf but do have _doprnt.  */
#undef HAVE_DOPRNT

/* Define if you have <sys/wait.h> that is POSIX.1 compatible.  */
#undef HAVE_SYS_WAIT_H

/* Define if you have the vprintf function.  */
#undef HAVE_VPRINTF

/* Define to `int' if <sys/types.h> doesn't define.  */
#undef mode_t

/* Define to `int' if <sys/types.h> doesn't define.  */
#undef pid_t

/* Define as the return type of signal handlers (int or void).  */
#undef RETSIGTYPE

/* Define to `unsigned' if <sys/types.h> doesn't define.  */
#undef size_t

/* Define if you have the snprintf function.  */
#undef HAVE_SNPRINTF

/* Define if you have the vsnprintf function.  */
#undef HAVE_VSNPRINTF

/* Define if you have the ANSI C header files.  */
#undef STDC_HEADERS

/* Define on System V Release 4.  */
#undef SVR4

/* Define if you can safely include both <sys/time.h> and <time.h>.  */
#undef TIME_WITH_SYS_TIME

/* Define if the X Window System is missing or not being used.  */
#undef X_DISPLAY_MISSING

/* Define if you have X11 library */
#undef HasX11

/* Include patented LZW compression */
#undef HasLZW

/* X11 server supports shape extension */
#undef HasShape

/* X11 server supports shared memory extension */
#undef HasSharedMemory

/* Increase max color value from 255 to 65535 */
#undef QuantumLeap

/* Location of X11 RGB database */
#undef RGBColorDatabase

/* Define if you have the bzip2 library */
#undef HasBZLIB

/* Define if you have Display Postscript */
#undef HasDPS

/* Define if you have FlashPIX library */
#undef HasFPX

/* Define if you have HDF library */
#undef HasHDF

/* Define if you have JBIG library */
#undef HasJBIG

/* Define if you have JPEG library */
#undef HasJPEG

/* Define if you have MPEG library */
#undef HasMPEG

/* Define if you have PNG library */
#undef HasPNG

/* Define if you have TIFF library */
#undef HasTIFF

/* Define if you have FreeType (TrueType font) library */
#undef HasTTF

/* Define to specify default TrueType font path. */
#undef TT_FONT_PATH

/* Define if you have the SFIO mmap-based stdio library emulation */
#undef HasSFIO

/* Define if you have zlib compression library */
#undef HasZLIB

/* Define if you have debugging malloc library */
#undef WITH_DMALLOC

/* Define if you have sys_errlist[] in libc */
#undef HAVE_SYS_ERRLIST

/* Define if you have the getcwd function.  */
#undef HAVE_GETCWD

/* Define if you have the gethostname function.  */
#undef HAVE_GETHOSTNAME

/* Define if you have the mkdir function.  */
#undef HAVE_MKDIR

/* Define if you have the select function.  */
#undef HAVE_SELECT

/* Define if you have the strcspn function.  */
#undef HAVE_STRCSPN

/* Define if you have the strerror function.  */
#undef HAVE_STRERROR

/* Define if you have the strtol function.  */
#undef HAVE_STRTOL

/* Define if you have the <dirent.h> header file.  */
#undef HAVE_DIRENT_H

/* Define if you have the <fcntl.h> header file.  */
#undef HAVE_FCNTL_H

/* Define if you have the <ndir.h> header file.  */
#undef HAVE_NDIR_H

/* Define if you have the <strings.h> header file.  */
#undef HAVE_STRINGS_H

/* Define if you have the <sys/dir.h> header file.  */
#undef HAVE_SYS_DIR_H

/* Define if you have the <sys/file.h> header file.  */
#undef HAVE_SYS_FILE_H

/* Define if you have the <sys/ndir.h> header file.  */
#undef HAVE_SYS_NDIR_H

/* Define if you have the <sys/time.h> header file.  */
#undef HAVE_SYS_TIME_H

/* Define if you have the <unistd.h> header file.  */
#undef HAVE_UNISTD_H

/* Define if you have HP style pty allocation (/dev/ptym/ptyp*) */
#undef HAVE_PTYM

/* Define if you have HP style pty trapping (struct.*request_info in sys/ptyio.h) */
#undef HAVE_PTYTRAP

/* Define if you have AIX new-style pty allocation (/dev/ptc && /dev/pts) */
#undef HAVE_PTC_PTS

/* Define if you have SGI old-style pty allocation (/dev/ptc && ! /dev/pts) */
#undef HAVE_PTC

/* Define if you have SCO style pty allocation */
#undef HAVE_SCO_CLIST_PTYS

/* Define if you have SVR4 style pty allocation (/dev/ptmx) */
#undef HAVE_PTMX

/* Define if you have OSF/1 style pty allocation (/dev/ptmx_bsd) */
#undef HAVE_PTMX_BSD

/* Define directory where ImageMagick/delegates.h lives. (default /usr/local/share) */
#undef DelegatePath

/* Define location of 'bzip2' program */
#undef BZIPDelegate

/* Define location of 'compress' program */
#undef LZWEncodeDelegate

/* Define location of 'uncompress' program */
#undef LZWDecodeDelegate

/* Define location of 'gzip' program */
#undef ZipDelegate

/* Define location of WWW 'GET' program */
#undef WWWDecodeDelegate

/* Define location of 'hp2xx' program */
#undef HPGLDecodeDelegate

/* Define location of 'html2ps' program */
#undef HTMLDecodeDelegate

/* Define location of 'pgpv' program */
#undef PGPDecodeDelegate

/* Define location of the CGM support program 'ralcgm' */
#undef CGMDecodeDelegate

/* Define location of the Fig support program 'fig2dev' */
#undef FIGDecodeDelegate

/* Define location of the Postscript support program 'ps' */
#undef PSDelegate

/* Define location of the MPEG support program 'mpeg2decode' */
#undef MPEGDecodeDelegate

/* Define location of the MPEG support program 'mpeg2encode' */
#undef MPEGEncodeDelegate

/* Define location of the Radiance support program 'ra_ppm' */
#undef RADDecodeDelegate

/* Define location of the 'rawtorle' program */
#undef RLEEncodeDelegate

/* Define location of the 'scanimage' program */
#undef SCANDecodeDelegate

/* Define location of the 'netscape' program */
#undef BrowseDelegate

/* Define location of the 'groff' program */
#undef MANDelegate

/* Define location of the 'gimp' program */
#undef LaunchDelegate

/* Define location of the 'xterm' program */
#undef EditorDelegate

/* Define location of the 'display' program */
#undef ShowImageDelegate

/* Define location of the 'gimp' program */
#undef POVDelegate

/* Define location of the 'lp' program */
#undef LPDelegate

/* Define location of the 'convert' program */
#undef ConvertDelegate

/* Define location of the 'mogrify' program */
#undef MogrifyDelegate

/* Define location of the 'mv' program */
#undef MVDelegate

/* Define location of the 'rm' program */
#undef RMDelegate

/* Define location of the 'cat' program */
#undef CatDelegate

/* Define location of 'enscript' program */
#undef TXTDelegate
